{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#InterProScan-v5-none_docker.cwl",
            "baseCommand": "interproscan.sh",
            "inputs": [
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/inputFile",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--input"
                    },
                    "label": "Input file path",
                    "doc": "Optional, path to fasta file that should be loaded on Master startup. Alternatively, in CONVERT mode, the InterProScan 5 XML file to convert."
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/applications",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 9,
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "label": "Analysis",
                    "doc": "Optional, comma separated list of analyses. If this option is not set, ALL analyses will be run."
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/outputFormat",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 10,
                        "itemSeparator": ",",
                        "prefix": "--formats"
                    },
                    "label": "output format",
                    "doc": "Optional, case-insensitive, comma separated list of output formats. Supported formats are TSV, XML, JSON, GFF3, HTML and SVG. Default for protein sequences are TSV, XML and GFF3, or for nucleotide sequences GFF3 and XML."
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/databases",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/disableResidueAnnotation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--disable-residue-annot"
                    },
                    "label": "Disables residue annotation",
                    "doc": "Optional, excludes sites from the XML, JSON output."
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/seqtype",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#InterProScan-v5-none_docker.cwl/i5/seqtype/seqtype/p",
                                "#InterProScan-v5-none_docker.cwl/i5/seqtype/seqtype/n"
                            ],
                            "name": "#InterProScan-v5-none_docker.cwl/i5/seqtype/seqtype"
                        }
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--seqtype"
                    },
                    "label": "Sequence type",
                    "doc": "Optional, the type of the input sequences (dna/rna (n) or protein (p)). The default sequence type is protein."
                }
            ],
            "doc": "InterProScan is the software package that allows sequences (protein and nucleic) to be scanned against InterPro's signatures. Signatures are predictive models, provided by several different databases, that make up the InterPro consortium. This tool description is using a Docker container tagged as version v5.30-69.0. Documentation on how to run InterProScan 5 can be found here: https://github.com/ebi-pf-team/interproscan/wiki/HowToRun",
            "label": "InterProScan: protein sequence classifier",
            "arguments": [
                {
                    "position": 0,
                    "valueFrom": "--disable-precalc"
                },
                {
                    "position": 1,
                    "valueFrom": "--goterms"
                },
                {
                    "position": 2,
                    "valueFrom": "--pathways"
                },
                {
                    "position": 3,
                    "prefix": "--tempdir",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 15000,
                    "coresMin": 4
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "http://schema.org/author": "Michael Crusoe, Aleksandra Ola Tarkowska, Maxim Scheremetjew",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "outputs": [
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/i5Annotations",
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.inputFile.nameroot).f*.tsv"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "split FAA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 8000,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#protein_chunker.cwl/chunk_size"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#protein_chunker.cwl/file_format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#protein_chunker.cwl/seqs"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "> /dev/null",
                    "shellQuote": false,
                    "position": 10
                },
                {
                    "valueFrom": "2> /dev/null",
                    "shellQuote": false,
                    "position": 11
                }
            ],
            "baseCommand": [
                "split_to_chunks.py"
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_*"
                    },
                    "id": "#protein_chunker.cwl/chunks"
                }
            ],
            "id": "#protein_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Redirecting Multiple Files Contain in a Single File",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "baseCommand": [
                "cat"
            ],
            "inputs": [
                {
                    "type": [
                        {
                            "type": "array",
                            "items": [
                                "File",
                                "string"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concatenate.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#concatenate.cwl/outputFileName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#concatenate.cwl/postfix"
                }
            ],
            "stdout": "$(inputs.outputFileName)$(inputs.postfix)",
            "outputs": [
                {
                    "id": "#concatenate.cwl/result",
                    "type": "File",
                    "format": "${if ((typeof(inputs.files[0]) == 'string') || (inputs.files.length == 0)) return 'undefined'; else { if (\"format\" in inputs.files[0]) return inputs.files[0].format; else return 'undefined'} }",
                    "outputBinding": {
                        "glob": "$(inputs.outputFileName)$(inputs.postfix)"
                    }
                }
            ],
            "doc": "The cat (short for concatenate) command is one of the most frequently used command in Linux/Unix like operating systems. cat command allows us to create single or multiple files, view contain of file, concatenate files and redirect output in terminal or files.\n",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 200,
                    "coresMax": 1
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "id": "#concatenate.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 1000,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/CGC_predicted_proteins"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/InterProScan_applications"
                },
                {
                    "type": "string",
                    "id": "#main/InterProScan_databases"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/InterProScan_outputFormat"
                },
                {
                    "type": "int",
                    "id": "#main/chunk_size"
                },
                {
                    "type": "string",
                    "id": "#main/name_ips"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/combine_ips/result",
                    "id": "#main/ips_result"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/interproscan/i5Annotations",
                            "id": "#main/combine_ips/files"
                        },
                        {
                            "source": "#main/CGC_predicted_proteins",
                            "valueFrom": "$(self.nameroot.split('_CDS')[0])",
                            "id": "#main/combine_ips/outputFileName"
                        },
                        {
                            "source": "#main/name_ips",
                            "id": "#main/combine_ips/postfix"
                        }
                    ],
                    "out": [
                        "#main/combine_ips/result"
                    ],
                    "run": "#concatenate.cwl",
                    "id": "#main/combine_ips"
                },
                {
                    "scatter": "#main/interproscan/inputFile",
                    "in": [
                        {
                            "source": "#main/InterProScan_applications",
                            "id": "#main/interproscan/applications"
                        },
                        {
                            "source": "#main/InterProScan_databases",
                            "id": "#main/interproscan/databases"
                        },
                        {
                            "source": "#main/split_seqs/chunks",
                            "id": "#main/interproscan/inputFile"
                        },
                        {
                            "source": "#main/InterProScan_outputFormat",
                            "id": "#main/interproscan/outputFormat"
                        }
                    ],
                    "out": [
                        "#main/interproscan/i5Annotations"
                    ],
                    "run": "#InterProScan-v5-none_docker.cwl",
                    "label": "InterProScan: protein sequence classifier",
                    "id": "#main/interproscan"
                },
                {
                    "in": [
                        {
                            "source": "#main/chunk_size",
                            "id": "#main/split_seqs/chunk_size"
                        },
                        {
                            "source": "#main/CGC_predicted_proteins",
                            "id": "#main/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#main/split_seqs/chunks"
                    ],
                    "run": "#protein_chunker.cwl",
                    "id": "#main/split_seqs"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.20.owl",
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
